@@ -28,10 +28,8 @@ typedef struct _NautilusClipboard NautilusClipboard;
 #define NAUTILUS_TYPE_CLIPBOARD (nautilus_clipboard_get_type())
 GType              nautilus_clipboard_get_type     (void);
 
-#if 0 && NAUTILUS_DND_NEEDS_GTK4_REIMPLEMENTATION
 void nautilus_clipboard_clear_if_colliding_uris    (GtkWidget          *widget,
                                                     const GList        *item_uris);
-#endif
 GList             *nautilus_clipboard_peek_files   (NautilusClipboard *clip);
 GList             *nautilus_clipboard_get_uri_list (NautilusClipboard *clip);
 gboolean           nautilus_clipboard_is_cut       (NautilusClipboard *clip);
